Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2420)

Unified Diff: chrome/test/automation/tab_proxy.h

Issue 174015: Add automation call to wait for multiple navigations. (Closed)
Patch Set: backwards compatibility, properly done Created 11 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/test/automation/automation_proxy_uitest.cc ('k') | chrome/test/automation/tab_proxy.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/test/automation/tab_proxy.h
diff --git a/chrome/test/automation/tab_proxy.h b/chrome/test/automation/tab_proxy.h
index 5e832274e7c6a487fd7bdcab4ef985f450b4689d..2c19bead8e0aac1e3ee952994b1edb8e97fb3c75 100644
--- a/chrome/test/automation/tab_proxy.h
+++ b/chrome/test/automation/tab_proxy.h
@@ -77,13 +77,23 @@ class TabProxy : public AutomationResourceProxy {
// Navigates to a url. This method accepts the same kinds of URL input that
// can be passed to Chrome on the command line. This is a synchronous call and
// hence blocks until the navigation completes.
- AutomationMsg_NavigationResponseValues NavigateToURL(const GURL& url);
+ AutomationMsg_NavigationResponseValues NavigateToURL(
+ const GURL& url);
+
+ // Navigates to a url. This method accepts the same kinds of URL input that
+ // can be passed to Chrome on the command line. This is a synchronous call and
+ // hence blocks until the |number_of_navigations| navigations complete.
+ AutomationMsg_NavigationResponseValues
+ NavigateToURLBlockUntilNavigationsComplete(const GURL& url,
+ int number_of_navigations);
// Navigates to a url. This is same as NavigateToURL with a timeout option.
// The function returns until the navigation completes or timeout (in
// milliseconds) occurs. If return after timeout, is_timeout is set to true.
AutomationMsg_NavigationResponseValues NavigateToURLWithTimeout(
- const GURL& url, uint32 timeout_ms, bool* is_timeout);
+ const GURL& url, int number_of_navigations, uint32 timeout_ms,
+ bool* is_timeout);
// Navigates to a url in an externally hosted tab.
// This method accepts the same kinds of URL input that
« no previous file with comments | « chrome/test/automation/automation_proxy_uitest.cc ('k') | chrome/test/automation/tab_proxy.cc » ('j') | no next file with comments »
@@ -77,13 +77,23 @@ class TabProxy : public AutomationResourceProxy {
// Navigates to a url. This is same as NavigateToURL with a timeout option.
- // The function returns until the navigation completes or timeout (in
- // milliseconds) occurs. If return after timeout, is_timeout is set to true.
+ // The function blocks until the |number_of_navigations| navigations
+ // completes or timeout (in milliseconds) occurs. If return after timeout,
+ // is_timeout is set to true.
AutomationMsg_NavigationResponseValues NavigateToURLWithTimeout(

Powered by Google App Engine
This is Rietveld 408576698